"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SuiSigner = exports.getSuiSigner = void 0;
const ed25519_1 = require("@mysten/sui.js/keypairs/ed25519");
const platform_js_1 = require("./platform.js");
async function getSuiSigner(rpc, privateKey) {
    const [, chain] = await platform_js_1.SuiPlatform.chainFromRpc(rpc);
    return new SuiSigner(chain, rpc, ed25519_1.Ed25519Keypair.deriveKeypair(privateKey, "m/44'/784'/0'/0'/0'"));
}
exports.getSuiSigner = getSuiSigner;
// SuiSigner implements SignOnlySender
class SuiSigner {
    _chain;
    _client;
    _signer;
    _debug;
    constructor(_chain, _client, _signer, _debug) {
        this._chain = _chain;
        this._client = _client;
        this._signer = _signer;
        this._debug = _debug;
    }
    chain() {
        return this._chain;
    }
    address() {
        return this._signer.toSuiAddress();
    }
    async signAndSend(txns) {
        const txids = [];
        for (const tx of txns) {
            const { description, transaction } = tx;
            if (this._debug)
                console.log(`Signing ${description} for ${this.address()}`);
            const result = await this._client.signAndExecuteTransactionBlock({
                transactionBlock: transaction,
                signer: this._signer,
            });
            txids.push(result.digest);
        }
        return txids;
    }
}
exports.SuiSigner = SuiSigner;
//# sourceMappingURL=signer.js.map